==> mingw-w64-aws-sdk-cpp-1.9.311-1.src.tar.zst: aws-sdk-cpp-1.9.311/aws-cpp-sdk-panorama/include/aws/panorama/model/NetworkPayload.h <==
﻿/**
 * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * SPDX-License-Identifier: Apache-2.0.
 */

#pragma once
#include <aws/panorama/Panorama_EXPORTS.h>
#include <aws/panorama/model/EthernetPayload.h>
#include <aws/panorama/model/NtpPayload.h>
#include <utility>

namespace Aws
{
namespace Utils
{
namespace Json
{
  class JsonValue;
  class JsonView;
} // namespace Json
} // namespace Utils
namespace Panorama
{
namespace Model
{

  /**
   * <p>The network configuration for a device.</p><p><h3>See Also:</h3>   <a
   * href="http://docs.aws.amazon.com/goto/WebAPI/panorama-2019-07-24/NetworkPayload">AWS
   * API Reference</a></p>
   */
  class AWS_PANORAMA_API NetworkPayload
  {
  public:
    NetworkPayload();
    NetworkPayload(Aws::Utils::Json::JsonView jsonValue);
    NetworkPayload& operator=(Aws::Utils::Json::JsonView jsonValue);
    Aws::Utils::Json::JsonValue Jsonize() const;


    /**
     * <p>Settings for Ethernet port 0.</p>
     */
    inline const EthernetPayload& GetEthernet0() const{ return m_ethernet0; }

    /**
     * <p>Settings for Ethernet port 0.</p>
     */
    inline bool Ethernet0HasBeenSet() const { return m_ethernet0HasBeenSet; }

    /**
     * <p>Settings for Ethernet port 0.</p>
     */
    inline void SetEthernet0(const EthernetPayload& value) { m_ethernet0HasBeenSet = true; m_ethernet0 = value; }

    /**
     * <p>Settings for Ethernet port 0.</p>
     */
    inline void SetEthernet0(EthernetPayload&& value) { m_ethernet0HasBeenSet = true; m_ethernet0 = std::move(value); }

    /**
     * <p>Settings for Ethernet port 0.</p>
     */
    inline NetworkPayload& WithEthernet0(const EthernetPayload& value) { SetEthernet0(value); return *this;}

    /**
     * <p>Settings for Ethernet port 0.</p>
     */
    inline NetworkPayload& WithEthernet0(EthernetPayload&& value) { SetEthernet0(std::move(value)); return *this;}


    /**
     * <p>Settings for Ethernet port 1.</p>
     */
    inline const EthernetPayload& GetEthernet1() const{ return m_ethernet1; }

    /**
     * <p>Settings for Ethernet port 1.</p>
     */
    inline bool Ethernet1HasBeenSet() const { return m_ethernet1HasBeenSet; }

    /**
     * <p>Settings for Ethernet port 1.</p>
     */
    inline void SetEthernet1(const EthernetPayload& value) { m_ethernet1HasBeenSet = true; m_ethernet1 = value; }

    /**
     * <p>Settings for Ethernet port 1.</p>
     */
    inline void SetEthernet1(EthernetPayload&& value) { m_ethernet1HasBeenSet = true; m_ethernet1 = std::move(value); }

    /**
     * <p>Settings for Ethernet port 1.</p>
     */
    inline NetworkPayload& WithEthernet1(const EthernetPayload& value) { SetEthernet1(value); return *this;}

    /**
     * <p>Settings for Ethernet port 1.</p>
     */
    inline NetworkPayload& WithEthernet1(EthernetPayload&& value) { SetEthernet1(std::move(value)); return *this;}


    /**
     * <p>Network time protocol (NTP) server settings.</p>
     */
    inline const NtpPayload& GetNtp() const{ return m_ntp; }

    /**
     * <p>Network time protocol (NTP) server settings.</p>
     */
    inline bool NtpHasBeenSet() const { return m_ntpHasBeenSet; }

    /**
     * <p>Network time protocol (NTP) server settings.</p>
     */
    inline void SetNtp(const NtpPayload& value) { m_ntpHasBeenSet = true; m_ntp = value; }

    /**
     * <p>Network time protocol (NTP) server settings.</p>
     */
    inline void SetNtp(NtpPayload&& value) { m_ntpHasBeenSet = true; m_ntp = std::move(value); }

    /**
     * <p>Network time protocol (NTP) server settings.</p>
     */
    inline NetworkPayload& WithNtp(const NtpPayload& value) { SetNtp(value); return *this;}

    /**
     * <p>Network time protocol (NTP) server settings.</p>
     */
    inline NetworkPayload& WithNtp(NtpPayload&& value) { SetNtp(std::move(value)); return *this;}

  private:

    EthernetPayload m_ethernet0;
    bool m_ethernet0HasBeenSet;

    EthernetPayload m_ethernet1;
    bool m_ethernet1HasBeenSet;

    NtpPayload m_ntp;
    bool m_ntpHasBeenSet;
  };

} // namespace Model
} // namespace Panorama
} // namespace Aws

==> mingw-w64-aws-sdk-cpp-1.10.9-1.src.tar.zst: aws-sdk-cpp-1.10.9/aws-cpp-sdk-panorama/include/aws/panorama/model/NetworkPayload.h <==
﻿/**
 * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * SPDX-License-Identifier: Apache-2.0.
 */

#pragma once
#include <aws/panorama/Panorama_EXPORTS.h>
#include <aws/panorama/model/EthernetPayload.h>
#include <aws/panorama/model/NtpPayload.h>
#include <utility>

namespace Aws
{
namespace Utils
{
namespace Json
{
  class JsonValue;
  class JsonView;
} // namespace Json
} // namespace Utils
namespace Panorama
{
namespace Model
{

  /**
   * <p>The network configuration for a device.</p><p><h3>See Also:</h3>   <a
   * href="http://docs.aws.amazon.com/goto/WebAPI/panorama-2019-07-24/NetworkPayload">AWS
   * API Reference</a></p>
   */
  class AWS_PANORAMA_API NetworkPayload
  {
  public:
    NetworkPayload();
    NetworkPayload(Aws::Utils::Json::JsonView jsonValue);
    NetworkPayload& operator=(Aws::Utils::Json::JsonView jsonValue);
    Aws::Utils::Json::JsonValue Jsonize() const;


    /**
     * <p>Settings for Ethernet port 0.</p>
     */
    inline const EthernetPayload& GetEthernet0() const{ return m_ethernet0; }

    /**
     * <p>Settings for Ethernet port 0.</p>
     */
    inline bool Ethernet0HasBeenSet() const { return m_ethernet0HasBeenSet; }

    /**
     * <p>Settings for Ethernet port 0.</p>
     */
    inline void SetEthernet0(const EthernetPayload& value) { m_ethernet0HasBeenSet = true; m_ethernet0 = value; }

    /**
     * <p>Settings for Ethernet port 0.</p>
     */
    inline void SetEthernet0(EthernetPayload&& value) { m_ethernet0HasBeenSet = true; m_ethernet0 = std::move(value); }

    /**
     * <p>Settings for Ethernet port 0.</p>
     */
    inline NetworkPayload& WithEthernet0(const EthernetPayload& value) { SetEthernet0(value); return *this;}

    /**
     * <p>Settings for Ethernet port 0.</p>
     */
    inline NetworkPayload& WithEthernet0(EthernetPayload&& value) { SetEthernet0(std::move(value)); return *this;}


    /**
     * <p>Settings for Ethernet port 1.</p>
     */
    inline const EthernetPayload& GetEthernet1() const{ return m_ethernet1; }

    /**
     * <p>Settings for Ethernet port 1.</p>
     */
    inline bool Ethernet1HasBeenSet() const { return m_ethernet1HasBeenSet; }

    /**
     * <p>Settings for Ethernet port 1.</p>
     */
    inline void SetEthernet1(const EthernetPayload& value) { m_ethernet1HasBeenSet = true; m_ethernet1 = value; }

    /**
     * <p>Settings for Ethernet port 1.</p>
     */
    inline void SetEthernet1(EthernetPayload&& value) { m_ethernet1HasBeenSet = true; m_ethernet1 = std::move(value); }

    /**
     * <p>Settings for Ethernet port 1.</p>
     */
    inline NetworkPayload& WithEthernet1(const EthernetPayload& value) { SetEthernet1(value); return *this;}

    /**
     * <p>Settings for Ethernet port 1.</p>
     */
    inline NetworkPayload& WithEthernet1(EthernetPayload&& value) { SetEthernet1(std::move(value)); return *this;}


    /**
     * <p>Network time protocol (NTP) server settings.</p>
     */
    inline const NtpPayload& GetNtp() const{ return m_ntp; }

    /**
     * <p>Network time protocol (NTP) server settings.</p>
     */
    inline bool NtpHasBeenSet() const { return m_ntpHasBeenSet; }

    /**
     * <p>Network time protocol (NTP) server settings.</p>
     */
    inline void SetNtp(const NtpPayload& value) { m_ntpHasBeenSet = true; m_ntp = value; }

    /**
     * <p>Network time protocol (NTP) server settings.</p>
     */
    inline void SetNtp(NtpPayload&& value) { m_ntpHasBeenSet = true; m_ntp = std::move(value); }

    /**
     * <p>Network time protocol (NTP) server settings.</p>
     */
    inline NetworkPayload& WithNtp(const NtpPayload& value) { SetNtp(value); return *this;}

    /**
     * <p>Network time protocol (NTP) server settings.</p>
     */
    inline NetworkPayload& WithNtp(NtpPayload&& value) { SetNtp(std::move(value)); return *this;}

  private:

    EthernetPayload m_ethernet0;
    bool m_ethernet0HasBeenSet = false;

    EthernetPayload m_ethernet1;
    bool m_ethernet1HasBeenSet = false;

    NtpPayload m_ntp;
    bool m_ntpHasBeenSet = false;
  };

} // namespace Model
} // namespace Panorama
} // namespace Aws
